#!/usr/bin/env Rscript
#
# Compile some basic information about the twenty phenotypes analyzed in
# the mSphere manuscript.
#

is_binary = function(p) {
    p = p[!is.na(p)]
    all(p %in% c(0, 1))
}

projdir = '/home/tiffinp/epste051/project/metab_gwas'

strains = scan(file.path(projdir, 'data/strain/lists/153meliloti.txt'),
               what='character')
phenos = read.csv(file.path(projdir, 'results', 'tabulate_phenotypes',
                            '2017-07-12', 'phenotypes.mel153.tsv'),
                  sep='\t', as.is=TRUE, colClasses=c('strain'='character'),
                  check.names=FALSE)
nod_phenos = read.csv(file.path(projdir, 'data', 'phenotype',
                                'plant_data', '2017-06-30', 'adjusted_2017-07-12.tsv'),
                      sep='\t', header=TRUE, as.is=TRUE,
                      colClasses=c('strain'='character'))
nod_phenos = nod_phenos[nod_phenos[, 'strain'] %in% strains, ]

traits1 = names(phenos)[!(names(phenos) %in% c('strain', 'PC1', 'PC2',
                                               'weight_A17', 'weight_R108',
                                               'nodule_A17', 'nodule_R108'))]
traits2 = c('nodule_raw', 'weight_raw')

cat('Phenotype\tBinary\tN\tMean_or_One\tStdev_or_Zero\n')
for(ph in traits1) {
    p = phenos[, ph]
    n = sum(!is.na(p))
    if(is_binary(p)) {
        b = TRUE
        one = sum(!is.na(p) & p == 1)
        zero = sum(!is.na(p) & p == 0)
    } else {
        b = FALSE
        m = mean(p, na.rm=TRUE)
        s = sd(p, na.rm=TRUE)
    }
    cat(ph, '\t', as.numeric(b), '\t', n, '\t', sep='')
    if(b) {
        cat(one, '\t', zero, '\n', sep='')
    } else {
        cat(m, '\t', s, '\n', sep='')
    }
}

for(ph in traits2) {
    for(pg in c('A17', 'R108')) {
        p = nod_phenos[nod_phenos[, 'plant_genotype'] == pg, ph]
        n = sum(!is.na(p))
        b = 0
        m = mean(p, na.rm=TRUE)
        s = sd(p, na.rm=TRUE)
        cat(paste0(pg, '_', ph), '\t', as.numeric(b), '\t', n, '\t', sep='')
        cat(m, '\t', s, '\n', sep='')
    }
}
